@@ -134,7 +134,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -150,43 +150,43 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_dynamodb
-import aws_cdk.aws_ec2
-import aws_cdk.aws_ecs
-import constructs
+import aws_cdk.aws_dynamodb as _aws_cdk_aws_dynamodb_ceddda9d
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
+import aws_cdk.aws_ecs as _aws_cdk_aws_ecs_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class FargateToDynamoDB(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-fargate-dynamodb.FargateToDynamoDB",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         public_api: builtins.bool,
-        cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
+        cluster_props: typing.Optional[typing.Union[_aws_cdk_aws_ecs_ceddda9d.ClusterProps, typing.Dict[builtins.str, typing.Any]]] = None,
         container_definition_props: typing.Any = None,
-        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
+        dynamo_table_props: typing.Optional[typing.Union[_aws_cdk_aws_dynamodb_ceddda9d.TableProps, typing.Dict[builtins.str, typing.Any]]] = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
         ecr_repository_arn: typing.Optional[builtins.str] = None,
-        existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-        existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-        existing_table_interface: typing.Optional[aws_cdk.aws_dynamodb.ITable] = None,
-        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        existing_container_definition_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition] = None,
+        existing_fargate_service_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService] = None,
+        existing_table_interface: typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.ITable] = None,
+        existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
         fargate_service_props: typing.Any = None,
         fargate_task_definition_props: typing.Any = None,
         table_arn_environment_variable_name: typing.Optional[builtins.str] = None,
         table_environment_variable_name: typing.Optional[builtins.str] = None,
         table_permissions: typing.Optional[builtins.str] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
-        :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct. Default: - none
+        :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct.
         :param cluster_props: Optional properties to create a new ECS cluster.
         :param container_definition_props: -
         :param dynamo_table_props: Optional user provided props to override the default props for DynamoDB Table. Default: - Default props are used
@@ -204,29 +204,7 @@ class FargateToDynamoDB(
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. An DynamoDB Interface endpoint will be included in this VPC. Default: - none
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                public_api: builtins.bool,
-                cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
-                container_definition_props: typing.Any = None,
-                dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
-                ecr_image_version: typing.Optional[builtins.str] = None,
-                ecr_repository_arn: typing.Optional[builtins.str] = None,
-                existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-                existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-                existing_table_interface: typing.Optional[aws_cdk.aws_dynamodb.ITable] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                fargate_service_props: typing.Any = None,
-                fargate_task_definition_props: typing.Any = None,
-                table_arn_environment_variable_name: typing.Optional[builtins.str] = None,
-                table_environment_variable_name: typing.Optional[builtins.str] = None,
-                table_permissions: typing.Optional[builtins.str] = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8f669099000f03dcd7c38dccb42889260b2917b06111e3f3b2967e177e876c38)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = FargateToDynamoDBProps(
@@ -252,28 +230,28 @@ class FargateToDynamoDB(
 
     @builtins.property
     @jsii.member(jsii_name="container")
-    def container(self) -> aws_cdk.aws_ecs.ContainerDefinition:
-        return typing.cast(aws_cdk.aws_ecs.ContainerDefinition, jsii.get(self, "container"))
+    def container(self) -> _aws_cdk_aws_ecs_ceddda9d.ContainerDefinition:
+        return typing.cast(_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition, jsii.get(self, "container"))
 
     @builtins.property
     @jsii.member(jsii_name="dynamoTableInterface")
-    def dynamo_table_interface(self) -> aws_cdk.aws_dynamodb.ITable:
-        return typing.cast(aws_cdk.aws_dynamodb.ITable, jsii.get(self, "dynamoTableInterface"))
+    def dynamo_table_interface(self) -> _aws_cdk_aws_dynamodb_ceddda9d.ITable:
+        return typing.cast(_aws_cdk_aws_dynamodb_ceddda9d.ITable, jsii.get(self, "dynamoTableInterface"))
 
     @builtins.property
     @jsii.member(jsii_name="service")
-    def service(self) -> aws_cdk.aws_ecs.FargateService:
-        return typing.cast(aws_cdk.aws_ecs.FargateService, jsii.get(self, "service"))
+    def service(self) -> _aws_cdk_aws_ecs_ceddda9d.FargateService:
+        return typing.cast(_aws_cdk_aws_ecs_ceddda9d.FargateService, jsii.get(self, "service"))
 
     @builtins.property
     @jsii.member(jsii_name="vpc")
-    def vpc(self) -> aws_cdk.aws_ec2.IVpc:
-        return typing.cast(aws_cdk.aws_ec2.IVpc, jsii.get(self, "vpc"))
+    def vpc(self) -> _aws_cdk_aws_ec2_ceddda9d.IVpc:
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.IVpc, jsii.get(self, "vpc"))
 
     @builtins.property
     @jsii.member(jsii_name="dynamoTable")
-    def dynamo_table(self) -> typing.Optional[aws_cdk.aws_dynamodb.Table]:
-        return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.Table], jsii.get(self, "dynamoTable"))
+    def dynamo_table(self) -> typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.Table]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.Table], jsii.get(self, "dynamoTable"))
 
 
 @jsii.data_type(
@@ -303,24 +281,24 @@ class FargateToDynamoDBProps:
         self,
         *,
         public_api: builtins.bool,
-        cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
+        cluster_props: typing.Optional[typing.Union[_aws_cdk_aws_ecs_ceddda9d.ClusterProps, typing.Dict[builtins.str, typing.Any]]] = None,
         container_definition_props: typing.Any = None,
-        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
+        dynamo_table_props: typing.Optional[typing.Union[_aws_cdk_aws_dynamodb_ceddda9d.TableProps, typing.Dict[builtins.str, typing.Any]]] = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
         ecr_repository_arn: typing.Optional[builtins.str] = None,
-        existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-        existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-        existing_table_interface: typing.Optional[aws_cdk.aws_dynamodb.ITable] = None,
-        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        existing_container_definition_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition] = None,
+        existing_fargate_service_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService] = None,
+        existing_table_interface: typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.ITable] = None,
+        existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
         fargate_service_props: typing.Any = None,
         fargate_task_definition_props: typing.Any = None,
         table_arn_environment_variable_name: typing.Optional[builtins.str] = None,
         table_environment_variable_name: typing.Optional[builtins.str] = None,
         table_permissions: typing.Optional[builtins.str] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
-        :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct. Default: - none
+        :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct.
         :param cluster_props: Optional properties to create a new ECS cluster.
         :param container_definition_props: -
         :param dynamo_table_props: Optional user provided props to override the default props for DynamoDB Table. Default: - Default props are used
@@ -338,33 +316,13 @@ class FargateToDynamoDBProps:
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. An DynamoDB Interface endpoint will be included in this VPC. Default: - none
         '''
         if isinstance(cluster_props, dict):
-            cluster_props = aws_cdk.aws_ecs.ClusterProps(**cluster_props)
+            cluster_props = _aws_cdk_aws_ecs_ceddda9d.ClusterProps(**cluster_props)
         if isinstance(dynamo_table_props, dict):
-            dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
+            dynamo_table_props = _aws_cdk_aws_dynamodb_ceddda9d.TableProps(**dynamo_table_props)
         if isinstance(vpc_props, dict):
-            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+            vpc_props = _aws_cdk_aws_ec2_ceddda9d.VpcProps(**vpc_props)
         if __debug__:
-            def stub(
-                *,
-                public_api: builtins.bool,
-                cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
-                container_definition_props: typing.Any = None,
-                dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
-                ecr_image_version: typing.Optional[builtins.str] = None,
-                ecr_repository_arn: typing.Optional[builtins.str] = None,
-                existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-                existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-                existing_table_interface: typing.Optional[aws_cdk.aws_dynamodb.ITable] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                fargate_service_props: typing.Any = None,
-                fargate_task_definition_props: typing.Any = None,
-                table_arn_environment_variable_name: typing.Optional[builtins.str] = None,
-                table_environment_variable_name: typing.Optional[builtins.str] = None,
-                table_permissions: typing.Optional[builtins.str] = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f16d47b4e52c89df9c24841843144e557bb56ab11c40415ff1cc8d01e2a5b91f)
             check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
             check_type(argname="argument cluster_props", value=cluster_props, expected_type=type_hints["cluster_props"])
             check_type(argname="argument container_definition_props", value=container_definition_props, expected_type=type_hints["container_definition_props"])
@@ -381,7 +339,7 @@ class FargateToDynamoDBProps:
             check_type(argname="argument table_environment_variable_name", value=table_environment_variable_name, expected_type=type_hints["table_environment_variable_name"])
             check_type(argname="argument table_permissions", value=table_permissions, expected_type=type_hints["table_permissions"])
             check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "public_api": public_api,
         }
         if cluster_props is not None:
@@ -421,18 +379,16 @@ class FargateToDynamoDBProps:
 
         This has implications for the VPC deployed
         by this construct.
-
-        :default: - none
         '''
         result = self._values.get("public_api")
         assert result is not None, "Required property 'public_api' is missing"
         return typing.cast(builtins.bool, result)
 
     @builtins.property
-    def cluster_props(self) -> typing.Optional[aws_cdk.aws_ecs.ClusterProps]:
+    def cluster_props(self) -> typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ClusterProps]:
         '''Optional properties to create a new ECS cluster.'''
         result = self._values.get("cluster_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_ecs.ClusterProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ClusterProps], result)
 
     @builtins.property
     def container_definition_props(self) -> typing.Any:
@@ -440,13 +396,15 @@ class FargateToDynamoDBProps:
         return typing.cast(typing.Any, result)
 
     @builtins.property
-    def dynamo_table_props(self) -> typing.Optional[aws_cdk.aws_dynamodb.TableProps]:
+    def dynamo_table_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.TableProps]:
         '''Optional user provided props to override the default props for DynamoDB Table.
 
         :default: - Default props are used
         '''
         result = self._values.get("dynamo_table_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.TableProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.TableProps], result)
 
     @builtins.property
     def ecr_image_version(self) -> typing.Optional[builtins.str]:
@@ -470,14 +428,14 @@ class FargateToDynamoDBProps:
     @builtins.property
     def existing_container_definition_object(
         self,
-    ) -> typing.Optional[aws_cdk.aws_ecs.ContainerDefinition]:
+    ) -> typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition]:
         result = self._values.get("existing_container_definition_object")
-        return typing.cast(typing.Optional[aws_cdk.aws_ecs.ContainerDefinition], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition], result)
 
     @builtins.property
     def existing_fargate_service_object(
         self,
-    ) -> typing.Optional[aws_cdk.aws_ecs.FargateService]:
+    ) -> typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService]:
         '''A Fargate Service already instantiated (probably by another Solutions Construct).
 
         If
@@ -489,19 +447,21 @@ class FargateToDynamoDBProps:
         :default: - none
         '''
         result = self._values.get("existing_fargate_service_object")
-        return typing.cast(typing.Optional[aws_cdk.aws_ecs.FargateService], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService], result)
 
     @builtins.property
-    def existing_table_interface(self) -> typing.Optional[aws_cdk.aws_dynamodb.ITable]:
+    def existing_table_interface(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.ITable]:
         '''Optional user provided props to override the default props for DynamoDB Table.
 
         :default: - None
         '''
         result = self._values.get("existing_table_interface")
-        return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.ITable], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.ITable], result)
 
     @builtins.property
-    def existing_vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+    def existing_vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc]:
         '''An existing VPC in which to deploy the construct.
 
         Providing both this and
@@ -512,7 +472,7 @@ class FargateToDynamoDBProps:
         :default: - none
         '''
         result = self._values.get("existing_vpc")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], result)
 
     @builtins.property
     def fargate_service_props(self) -> typing.Any:
@@ -558,7 +518,7 @@ class FargateToDynamoDBProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def vpc_props(self) -> typing.Optional[aws_cdk.aws_ec2.VpcProps]:
+    def vpc_props(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.VpcProps]:
         '''Optional custom properties for a VPC the construct will create.
 
         This VPC will
@@ -570,7 +530,7 @@ class FargateToDynamoDBProps:
         :default: - none
         '''
         result = self._values.get("vpc_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.VpcProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.VpcProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -590,3 +550,49 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__8f669099000f03dcd7c38dccb42889260b2917b06111e3f3b2967e177e876c38(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    public_api: builtins.bool,
+    cluster_props: typing.Optional[typing.Union[_aws_cdk_aws_ecs_ceddda9d.ClusterProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    container_definition_props: typing.Any = None,
+    dynamo_table_props: typing.Optional[typing.Union[_aws_cdk_aws_dynamodb_ceddda9d.TableProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    ecr_image_version: typing.Optional[builtins.str] = None,
+    ecr_repository_arn: typing.Optional[builtins.str] = None,
+    existing_container_definition_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition] = None,
+    existing_fargate_service_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService] = None,
+    existing_table_interface: typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.ITable] = None,
+    existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    fargate_service_props: typing.Any = None,
+    fargate_task_definition_props: typing.Any = None,
+    table_arn_environment_variable_name: typing.Optional[builtins.str] = None,
+    table_environment_variable_name: typing.Optional[builtins.str] = None,
+    table_permissions: typing.Optional[builtins.str] = None,
+    vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f16d47b4e52c89df9c24841843144e557bb56ab11c40415ff1cc8d01e2a5b91f(
+    *,
+    public_api: builtins.bool,
+    cluster_props: typing.Optional[typing.Union[_aws_cdk_aws_ecs_ceddda9d.ClusterProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    container_definition_props: typing.Any = None,
+    dynamo_table_props: typing.Optional[typing.Union[_aws_cdk_aws_dynamodb_ceddda9d.TableProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    ecr_image_version: typing.Optional[builtins.str] = None,
+    ecr_repository_arn: typing.Optional[builtins.str] = None,
+    existing_container_definition_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition] = None,
+    existing_fargate_service_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService] = None,
+    existing_table_interface: typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.ITable] = None,
+    existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    fargate_service_props: typing.Any = None,
+    fargate_task_definition_props: typing.Any = None,
+    table_arn_environment_variable_name: typing.Optional[builtins.str] = None,
+    table_environment_variable_name: typing.Optional[builtins.str] = None,
+    table_permissions: typing.Optional[builtins.str] = None,
+    vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
